@@ -8,6 +8,10 @@ gencode_tracking_system::scripts::update
 Helper script for the AnnoTrack tracking system.
 Test servers and run update process for every source as defined in config.
 
+=head1 SYNOPSIS
+
+perl annotrack/perl/scripts/update.pl -write -env prod
+
 =head1 CONTACT
 
 Felix Kokocinski, fsk@sanger.ac.uk
@@ -63,6 +67,8 @@ my $mailcount = 0;
 my $update;
 my $das_connection;
 
+gencode_tracking_system::config->set_databases();
+
 #connect to tracking system db
 my $tracking_dbh = connect_db($DBHOST, $DBPORT, $DBNAME, $DBUSER, $DBPASS);
 
