@@ -53,6 +53,12 @@ class IssuesController < ApplicationController
 
   def index_annotrack
 
+    #check parameters
+    if(@template.check_input_string(params[:set_filter]) + @template.check_input_string(params[:flag]) + @template.check_input_string(params[:category]) > 0)
+      redirect_to :controller => 'welcome', :action => 'index'
+      return
+    end
+
     @set_filter = params[:set_filter]
     @flag_name = params[:flag]
     @category_name = params[:category]
@@ -80,6 +86,7 @@ class IssuesController < ApplicationController
                          :conditions => filterquery,
                          :limit  =>  limit,
                          :offset =>  @issue_pages.current.offset
+logger.debug("TOP, " + @issue_count.to_s)
       respond_to do |format|
         format.html { render :template => 'issues/index.rhtml', :layout => !request.xhr? }
         format.atom { render_feed(@issues, :title => "#{@project || Setting.app_title}: #{l(:label_issue_plural)}") }
@@ -129,13 +136,12 @@ class IssuesController < ApplicationController
     end
 
     # flash[:notice] = "INFILTER " + filterquery
-
     sort_init 'id', 'desc'
     sort_update({'id' => "#{Issue.table_name}.id"}.merge(@query.columns.inject({}) {|h, c| h[c.name.to_s] = c.sortable; h}))
 
     @issue_count = 0
     ## THIS IS TOO SLOW, added hack to store value in database, cronjob updates this hourly ##
-    if(@query.statement.eql?($defaultquery))
+    if(@filterquery.eql?($defaultquery))
       issue_query = ActiveRecord::Base.connection.execute("SELECT field_value from tmp_values WHERE field_name='default_count'")
       @issue_count = issue_query.fetch_row[0].to_i
       issue_query.free
